commands

package
v0.0.0-...-f92de01 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 5, 2023 License: BSD-3-Clause Imports: 6 Imported by: 0

Documentation

Overview

Copyright 2022 Practically.io All rights reserved

Use of this source is governed by a BSD-style licence that can be found in the LICENCE file or at https://www.practically.io/copyright

Use of this source is governed by a BSD-style licence that can be found in the LICENCE file or at https://www.practically.io/copyright

Use of this source is governed by a BSD-style licence that can be found in the LICENCE file or at https://www.practically.io/copyright

Use of this source is governed by a BSD-style licence that can be found in the LICENCE file or at https://www.practically.io/copyright

Index

Constants

const COMMAND_LIST_PADDING = 1

Variables

This section is empty.

Functions

func Help

func Help(application Application, config config.Config) error

func List

func List(application Application, config config.Config) error

func Run

func Run(application Application, config config.Config) error

Types

type Application

type Application struct {
	Cwd       string
	Help      bool
	Arguments []string
}

Jump to