Documentation
¶
Overview ¶
Copyright 2022 Practically.io All rights reserved
Use of this source is governed by a BSD-style licence that can be found in the LICENCE file or at https://www.practically.io/copyright
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// The version number for this configuration. Currently this can only be
// "0.0.1"
Version string `json:"version"`
// A map of tasks that are keyed by the task identifier
Tasks map[string]Task `json:"tasks"`
}
The main configuration for all of the tasks
type Task ¶
type Task struct {
ID string
// The title of the task. This is what will be displayed in output
Title string `json:"title"`
// The log description of this task
Description string `json:"description"`
// The container that the command will be run in
Image string `json:"image"`
// The excitable for this task
Commands []Command `json:"commands"`
// A list of task ids that this task depends on
Requires []string `json:"requires"`
}
A single task definition
Click to show internal directories.
Click to hide internal directories.